"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.pdaForVault = exports.createVaultOwnedTokenAccount = exports.createUninitializedTokenAccount = exports.createTokenAccount = exports.getTokenRentExempt = exports.mintTokens = exports.createUninitializedMint = exports.getMintRentExempt = exports.createMint = exports.createAssociatedTokenAccount = exports.approveTokenTransfer = void 0;
const safe_token_1 = require("@safecoin/safe-token");
const web3_js_1 = require("@safecoin/web3.js");
const consts_1 = require("./consts");
function approveTokenTransfer({ sourceAccount, owner, amount, }) {
    const transferAuthority = web3_js_1.Keypair.generate();
    const createApproveIx = (0, safe_token_1.createApproveInstruction)(sourceAccount, transferAuthority.publicKey, owner, amount);
    return [createApproveIx, transferAuthority];
}
exports.approveTokenTransfer = approveTokenTransfer;
async function createAssociatedTokenAccount({ tokenMint, tokenOwner, payer, }) {
    const associatedTokenAccount = await (0, safe_token_1.getAssociatedTokenAddress)(tokenMint, tokenOwner);
    const createATAInstruction = (0, safe_token_1.createAssociatedTokenAccountInstruction)(payer, associatedTokenAccount, tokenOwner, tokenMint);
    return [createATAInstruction, associatedTokenAccount];
}
exports.createAssociatedTokenAccount = createAssociatedTokenAccount;
function createMint(payer, mintRentExempt, decimals, mintAuthority, freezeAuthority) {
    const [createMintIx, mintAccountPair, mintAccount] = createUninitializedMint(payer, mintRentExempt);
    const initMintIx = (0, safe_token_1.createInitializeMintInstruction)(mintAccount, decimals, mintAuthority, freezeAuthority);
    return [[createMintIx, initMintIx], [mintAccountPair], { mintAccountPair, mintAccount }];
}
exports.createMint = createMint;
function getMintRentExempt(connection) {
    return connection.getMinimumBalanceForRentExemption(safe_token_1.MintLayout.span);
}
exports.getMintRentExempt = getMintRentExempt;
function createUninitializedMint(payer, amount) {
    const mintAccount = web3_js_1.Keypair.generate();
    const instruction = web3_js_1.SystemProgram.createAccount({
        fromPubkey: payer,
        newAccountPubkey: mintAccount.publicKey,
        lamports: amount,
        space: safe_token_1.MintLayout.span,
        programId: safe_token_1.TOKEN_PROGRAM_ID,
    });
    return [instruction, mintAccount, mintAccount.publicKey];
}
exports.createUninitializedMint = createUninitializedMint;
function mintTokens(mint, tokenAccount, mintAuthority, amount) {
    return (0, safe_token_1.createMintToInstruction)(mint, tokenAccount, mintAuthority, amount);
}
exports.mintTokens = mintTokens;
function getTokenRentExempt(connection) {
    return connection.getMinimumBalanceForRentExemption(safe_token_1.AccountLayout.span);
}
exports.getTokenRentExempt = getTokenRentExempt;
function createTokenAccount(payer, accountRentExempt, mint, owner) {
    const [createAccountIx, signer, { tokenAccountPair, tokenAccount }] = createUninitializedTokenAccount(payer, accountRentExempt);
    const initAccountIx = (0, safe_token_1.createInitializeAccountInstruction)(tokenAccount, mint, owner);
    return [[createAccountIx, initAccountIx], [signer], { tokenAccountPair, tokenAccount }];
}
exports.createTokenAccount = createTokenAccount;
function createUninitializedTokenAccount(payer, amount) {
    const tokenAccountPair = web3_js_1.Keypair.generate();
    const instruction = web3_js_1.SystemProgram.createAccount({
        fromPubkey: payer,
        newAccountPubkey: tokenAccountPair.publicKey,
        lamports: amount,
        space: safe_token_1.AccountLayout.span,
        programId: safe_token_1.TOKEN_PROGRAM_ID,
    });
    return [
        instruction,
        tokenAccountPair,
        { tokenAccountPair, tokenAccount: tokenAccountPair.publicKey },
    ];
}
exports.createUninitializedTokenAccount = createUninitializedTokenAccount;
async function createVaultOwnedTokenAccount(connection, payer, vault, tokenMint) {
    const vaultPDA = await pdaForVault(vault);
    const tokenAccountRentExempt = await connection.getMinimumBalanceForRentExemption(safe_token_1.AccountLayout.span);
    const [instructions, signers, { tokenAccount }] = createTokenAccount(payer, tokenAccountRentExempt, tokenMint, vaultPDA);
    return [instructions, signers, { tokenAccount }];
}
exports.createVaultOwnedTokenAccount = createVaultOwnedTokenAccount;
async function pdaForVault(vault) {
    const [vaultPDA] = await web3_js_1.PublicKey.findProgramAddress([Buffer.from(consts_1.VAULT_PREFIX), consts_1.VAULT_PROGRAM_ID.toBuffer(), vault.toBuffer()], consts_1.VAULT_PROGRAM_ID);
    return vaultPDA;
}
exports.pdaForVault = pdaForVault;
//# sourceMappingURL=helpers.js.map