/// <reference types="node" />
import * as definedTypes from '../types';
import * as web3 from '@safecoin/web3.js';
import * as beet from '@j0nnyboi/beet';
export declare type VaultArgs = {
    key: definedTypes.Key;
    tokenProgram: web3.PublicKey;
    fractionMint: web3.PublicKey;
    authority: web3.PublicKey;
    fractionTreasury: web3.PublicKey;
    redeemTreasury: web3.PublicKey;
    allowFurtherShareCreation: boolean;
    pricingLookupAddress: web3.PublicKey;
    tokenTypeCount: number;
    state: definedTypes.VaultState;
    lockedPricePerShare: beet.bignum;
    extraByte: number;
};
export declare class Vault implements VaultArgs {
    readonly key: definedTypes.Key;
    readonly tokenProgram: web3.PublicKey;
    readonly fractionMint: web3.PublicKey;
    readonly authority: web3.PublicKey;
    readonly fractionTreasury: web3.PublicKey;
    readonly redeemTreasury: web3.PublicKey;
    readonly allowFurtherShareCreation: boolean;
    readonly pricingLookupAddress: web3.PublicKey;
    readonly tokenTypeCount: number;
    readonly state: definedTypes.VaultState;
    readonly lockedPricePerShare: beet.bignum;
    readonly extraByte: number;
    private constructor();
    static fromArgs(args: VaultArgs): Vault;
    static fromAccountInfo(accountInfo: web3.AccountInfo<Buffer>, offset?: number): [Vault, number];
    static fromAccountAddress(connection: web3.Connection, address: web3.PublicKey): Promise<Vault>;
    static deserialize(buf: Buffer, offset?: number): [Vault, number];
    serialize(): [Buffer, number];
    static get byteSize(): number;
    static getMinimumBalanceForRentExemption(connection: web3.Connection, commitment?: web3.Commitment): Promise<number>;
    static hasCorrectByteSize(buf: Buffer, offset?: number): boolean;
    pretty(): {
        key: string;
        tokenProgram: string;
        fractionMint: string;
        authority: string;
        fractionTreasury: string;
        redeemTreasury: string;
        allowFurtherShareCreation: boolean;
        pricingLookupAddress: string;
        tokenTypeCount: number;
        state: string;
        lockedPricePerShare: beet.bignum;
        extraByte: number;
    };
}
export declare const vaultBeet: beet.BeetStruct<Vault, VaultArgs>;
