"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createExternalPriceAccount = void 0;
const web3_js_1 = require("@safecoin/web3.js");
const generated_1 = require("../generated");
const lpl_token_vault_1 = require("../lpl-token-vault");
async function createExternalPriceAccount(connection, payer) {
    const externalPriceAccountPair = web3_js_1.Keypair.generate();
    const rentExempt = await connection.getMinimumBalanceForRentExemption(generated_1.ExternalPriceAccount.byteSize);
    const createExternalPriceAccountIx = web3_js_1.SystemProgram.createAccount({
        fromPubkey: payer,
        newAccountPubkey: externalPriceAccountPair.publicKey,
        lamports: rentExempt,
        space: generated_1.ExternalPriceAccount.byteSize,
        programId: new web3_js_1.PublicKey(lpl_token_vault_1.VAULT_PROGRAM_ADDRESS),
    });
    const externalPriceAccount = generated_1.ExternalPriceAccount.fromArgs({
        key: generated_1.Key.ExternalAccountKeyV1,
        pricePerShare: 0,
        priceMint: lpl_token_vault_1.QUOTE_MINT,
        allowedToCombine: true,
    });
    const args = {
        externalPriceAccount,
    };
    const accounts = {
        externalPriceAccount: externalPriceAccountPair.publicKey,
    };
    const updateExternalPriceAccountIx = (0, generated_1.createUpdateExternalPriceAccountInstruction)(accounts, args);
    return [
        [createExternalPriceAccountIx, updateExternalPriceAccountIx],
        [externalPriceAccountPair],
        { externalPriceAccount: externalPriceAccountPair.publicKey },
    ];
}
exports.createExternalPriceAccount = createExternalPriceAccount;
//# sourceMappingURL=create-external-price-account.js.map